@@ -9,39 +9,14 @@ filter 'Time::Moment'         => sub { _format($_[0]->to_string   , @_) };
 filter 'DateTime::TimeZone'   => sub { _format($_[0]->name        , @_) };
 filter 'DateTime::Incomplete' => sub { _format($_[0]->iso8601     , @_) };
 filter 'DateTime::Tiny'       => sub { _format($_[0]->as_string   , @_) };
+filter 'Date'                 => sub { _format($_[0]->to_string   , @_) };
 filter 'Date::Tiny'           => sub { _format($_[0]->as_string   , @_) };
 filter 'Date::Calc::Object'   => sub { _format($_[0]->string(2)   , @_) };
-filter 'Date::Pcalc::Object'  => sub { _format($_[0]->string(2)   , @_) };
 filter 'Date::Handler'        => sub { _format("$_[0]"            , @_) };
 filter 'Date::Handler::Delta' => sub { _format($_[0]->AsScalar    , @_) };
 filter 'Date::Simple'         => sub { _format("$_[0]"            , @_) };
 filter 'Date::Manip::Obj'     => sub { _format(scalar $_[0]->value, @_) };
 
-filter 'Panda::Date'      => sub { _format(_filter_Panda_Date(@_), @_) };
-filter 'Panda::Date::Rel' => sub { _format( "$_[0]", @_) };
-filter 'Panda::Date::Int' => sub {
-    my ($date, $ddp) = @_;
-    _format(
-          _filter_Panda_Date($date->from, $ddp)
-        . ' ~ '
-        . _filter_Panda_Date($date->till, $ddp),
-        @_
-    );
-};
-
-sub _filter_Panda_Date {
-    my ($date, $ddp) = @_;
-    my $string = $date->iso;
-    if (!exists $ddp->extra_config->{filter_datetime}{show_timezone}
-        || $ddp->extra_config->{filter_datetime}{show_timezone}
-    ) {
-        $string .= ' ' . $ddp->maybe_colorize('[', 'brackets')
-                 . $date->tzabbr
-                 . $ddp->maybe_colorize(']', 'brackets');
-    }
-    return $string;
-}
-
 filter 'Mojo::Date' => sub {
     my $date = $_[0]->can('to_datetime')
       ? $_[0]->to_datetime
@@ -215,12 +190,12 @@ as a string.
 
 =item * L<DateTime::Tiny>
 
+=item * L<Date>
+
 =item * L<Date::Tiny>
 
 =item * L<Date::Calc::Object>
 
-=item * L<Date::Pcalc::Object>
-
 =item * L<Date::Handler>, L<Date::Handler::Delta>
 
 =item * L<Date::Simple>
@@ -231,8 +206,6 @@ as a string.
 
 =item * L<Date::Manip>
 
-=item * L<Panda::Date>, L<Panda::Date::Rel>, L<Panda::Date::Int>
-
 =back
 
 If you have any suggestions for more modules or better output,
